import React, { useCallback } from 'react';
import cn from 'classnames';
import { IconButton } from '@alfalab/core-components-icon-button/dist/modern';
import { Link } from '@alfalab/core-components-link/dist/modern';
import { Spinner } from '@alfalab/core-components-spinner/dist/modern';
import { CrossMIcon } from '@alfalab/icons-glyph/CrossMIcon';
import { CheckmarkCircleMIcon } from '@alfalab/icons-glyph/CheckmarkCircleMIcon';
import { AlertCircleMIcon } from '@alfalab/icons-glyph/AlertCircleMIcon';
import '@alfalab/icons-glyph';
import { fileIcon, humanFileSize } from './utils.js';

var styles = {"component":"file-upload-item__component_171n7","info":"file-upload-item__info_171n7","icon":"file-upload-item__icon_171n7","errorIcon":"file-upload-item__errorIcon_171n7","successIcon":"file-upload-item__successIcon_171n7","name":"file-upload-item__name_171n7","meta":"file-upload-item__meta_171n7","size":"file-upload-item__size_171n7","delete":"file-upload-item__delete_171n7","error":"file-upload-item__error_171n7"};
require('./index.css')

const FileUploadItem = ({ className, children, id = '0', name = '', size, uploadDate, downloadLink, uploadStatus, uploadPercent = 0, error = uploadStatus === 'ERROR' ? 'Не удалось загрузить файл' : undefined, showDelete, showRestore, onDelete, onDownload, onRestore, dataTestId, }) => {
    const handleDownload = useCallback((event) => {
        if (onDownload) {
            event.preventDefault();
            onDownload(id);
        }
    }, [id, onDownload]);
    const handleDelete = useCallback(() => {
        if (onDelete)
            onDelete(id);
    }, [id, onDelete]);
    const handleRestore = useCallback(() => {
        if (onRestore)
            onRestore(id);
    }, [id, onRestore]);
    const renderIcon = useCallback(() => {
        switch (uploadStatus) {
            case 'ERROR':
                return React.createElement(AlertCircleMIcon, { className: styles.errorIcon });
            case 'SUCCESS':
                return React.createElement(CheckmarkCircleMIcon, { className: styles.successIcon });
            case 'LOADING':
            case 'UPLOADING':
                return React.createElement(Spinner, { visible: true });
            default: {
                const Icon = fileIcon(name);
                return React.createElement(Icon, { className: styles.icon });
            }
        }
    }, [name, uploadStatus]);
    const renderName = useCallback(() => (React.createElement("div", { className: styles.name }, downloadLink ? (React.createElement(Link, { pseudo: true, href: downloadLink, onClick: handleDownload }, name)) : (name))), [downloadLink, handleDownload, name]);
    const showMeta = !showRestore && (!uploadStatus || uploadStatus === 'SUCCESS');
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement("div", { className: styles.info },
            renderIcon(),
            renderName(),
            children,
            uploadStatus === 'UPLOADING' && React.createElement("span", null, `${Math.round(uploadPercent)}%`),
            uploadStatus === 'ERROR' && React.createElement("span", { className: styles.error }, error),
            showMeta && (React.createElement("div", { className: styles.meta },
                uploadDate && React.createElement("span", { key: uploadDate }, uploadDate),
                size && (React.createElement("span", { key: size, className: styles.size }, humanFileSize(size)))))),
        showRestore && (React.createElement(Link, { pseudo: true, className: styles.restore, onClick: handleRestore }, "\u0412\u043E\u0441\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C")),
        showDelete && !showRestore && (React.createElement(IconButton, { size: 'xxs', icon: CrossMIcon, onClick: handleDelete, className: styles.delete, "aria-label": '\u0443\u0434\u0430\u043B\u0438\u0442\u044C' }))));
};

export { FileUploadItem };
